pub trait Section: Encode {
// Required method
fn id(&self) -> u8;
// Provided method
fn append_to(&self, dst: &mut Vec<u8>) { ... }
}Expand description
A WebAssembly module section.
Various builders defined in this crate already implement this trait, but you
can also implement it yourself for your own custom section builders, or use
RawSection to use a bunch of raw bytes as a section.
Required Methods
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".